# Generated by Django 4.2.1 on 2023-12-12 01:18

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0009_alter_billingrecipt_option_alter_company_business_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='booking',
            name='service',
        ),
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('Others', 'Others'), ('budget_development', 'Budget Development'), ('budget_design', 'Budget Design'), ('budget_marketing', 'Budget Marketing'), ('Billing receipt', 'Billing receipt'), ('Monthly charge', 'Monthly charge')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Education and Training', 'Education and Training'), ('Health and Wellness', 'Health and Wellness'), ('Consulting', 'Consulting'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('IT Development Services', 'IT Development Services'), ('E-commerce', 'E-commerce'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Media Creators', 'Media Creators'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-tale', 'card-tale'), ('card-light-danger', 'card-light-danger'), ('card-light-blue', 'card-light-blue'), ('card-dark-blue', 'card-dark-blue')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('News', 'News'), ('Interviews', 'Interviews'), ('Guides and Manuals', 'Guides and Manuals'), ('Events and Conferences', 'Events and Conferences'), ('Tutorials', 'Tutorials'), ('Tips and Tricks', 'Tips and Tricks'), ('Inspiration', 'Inspiration')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 11, 22, 17, 57, 362250)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('Initial Payment', 'Initial Payment'), ('Promotional Discount', 'Promotional Discount'), ('No Selected', 'No Selected')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Send', 'Send'), ('Draft', 'Draft')], max_length=20),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Stela Design', 'Stela Design'), ('Store', 'Store'), ('No Selected', 'No Selected'), ('Stela Marketing', 'Stela Marketing'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('Stela Websites', 'Stela Websites'), ('Cloud Domains', 'Cloud Domains')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('Cookie Policy', 'Cookie Policy'), ('Terms and Conditions', 'Terms and Conditions'), ('budget_development_terms', 'Budget Development Terms'), ('Disclaimer', 'Disclaimer'), ('billing_terms', 'Monthly Billing Terms'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('monthly_terms', 'Billing Terms'), ('Return Policy', 'Return Policy'), ('Privacy Policy', 'Privacy Policy'), ('budget_design_terms', 'Budget Design Terms')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Linkedin', 'Linkedin'), ('Facebook', 'Facebook'), ('Instagram', 'Instagram'), ('X', 'X'), ('Github', 'Github'), ('Tiktok', 'Tiktok'), ('Youtube', 'Youtube')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('Others', 'Others'), ('My account has an error', 'My account has an error'), ('Payments Issue', 'Payments Issue'), ('My delivery has been delayed', 'My delivery has been delayed'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('I have a problem with my project', 'I have a problem with my project')], max_length=60, verbose_name='Case'),
        ),
    ]
