# Generated by Django 5.0 on 2023-12-17 17:16

import datetime
import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0013_alter_billingrecipt_option_alter_company_business_and_more'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.RemoveField(
            model_name='shareposts',
            name='post',
        ),
        migrations.RemoveField(
            model_name='sociallinks',
            name='parent',
        ),
        migrations.AddField(
            model_name='sociallinks',
            name='parent_company',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='company_social', to='stela_control.company'),
        ),
        migrations.AddField(
            model_name='sociallinks',
            name='parent_staff',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='staff_social', to='stela_control.team'),
        ),
        migrations.AddField(
            model_name='sociallinks',
            name='parent_user',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='owner_social', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('Billing receipt', 'Billing receipt'), ('budget_marketing', 'Budget Marketing'), ('budget_development', 'Budget Development'), ('budget_design', 'Budget Design'), ('Others', 'Others'), ('Monthly charge', 'Monthly charge')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('E-commerce', 'E-commerce'), ('Media Creators', 'Media Creators'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('Education and Training', 'Education and Training'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Health and Wellness', 'Health and Wellness'), ('Consulting', 'Consulting'), ('IT Development Services', 'IT Development Services')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-dark-blue', 'card-dark-blue'), ('card-light-danger', 'card-light-danger'), ('card-light-blue', 'card-light-blue'), ('card-tale', 'card-tale')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Tips and Tricks', 'Tips and Tricks'), ('Events and Conferences', 'Events and Conferences'), ('Inspiration', 'Inspiration'), ('Tutorials', 'Tutorials'), ('Interviews', 'Interviews'), ('News', 'News'), ('Guides and Manuals', 'Guides and Manuals')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 17, 14, 16, 20, 252097)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('Promotional Discount', 'Promotional Discount'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('No Selected', 'No Selected'), ('Initial Payment', 'Initial Payment')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Send', 'Send'), ('Draft', 'Draft')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 2', 'Style Template 2'), ('Style Template 1', 'Style Template 1'), ('Style Template 3', 'Style Template 3'), ('Style Template 4', 'Style Template 4')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Store', 'Store'), ('Stela Design', 'Stela Design'), ('No Selected', 'No Selected'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('Cloud Domains', 'Cloud Domains'), ('Stela Websites', 'Stela Websites'), ('Stela Marketing', 'Stela Marketing')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 3', 'Step 3'), ('Step 4', 'Step 4'), ('Step 2', 'Step 2')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('Return Policy', 'Return Policy'), ('budget_development_terms', 'Budget Development Terms'), ('Cookie Policy', 'Cookie Policy'), ('Terms and Conditions', 'Terms and Conditions'), ('monthly_terms', 'Billing Terms'), ('Privacy Policy', 'Privacy Policy'), ('budget_design_terms', 'Budget Design Terms'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('billing_terms', 'Monthly Billing Terms'), ('Disclaimer', 'Disclaimer')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Youtube', 'Youtube'), ('Instagram', 'Instagram'), ('Linkedin', 'Linkedin'), ('Github', 'Github'), ('X', 'X'), ('Tiktok', 'Tiktok'), ('Facebook', 'Facebook')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('I have a problem with my project', 'I have a problem with my project'), ('My account has an error', 'My account has an error'), ('Payments Issue', 'Payments Issue'), ('Others', 'Others'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('My delivery has been delayed', 'My delivery has been delayed')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50, null=True),
        ),
        migrations.DeleteModel(
            name='Poll',
        ),
        migrations.DeleteModel(
            name='SharePosts',
        ),
    ]
