# Generated by Django 5.0 on 2023-12-27 13:52

import datetime
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0019_remove_jobapplication_available_start_date_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Biography',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('date_of_birth', models.DateField()),
                ('place_of_birth', models.CharField(max_length=200)),
                ('nationality', models.CharField(max_length=100)),
                ('profession', models.CharField(max_length=100)),
                ('biography', models.TextField()),
            ],
        ),
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('Billing receipt', 'Billing receipt'), ('budget_development', 'Budget Development'), ('budget_marketing', 'Budget Marketing'), ('Others', 'Others'), ('budget_design', 'Budget Design'), ('Monthly charge', 'Monthly charge')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Restaurants and Food Services', 'Restaurants and Food Services'), ('Consulting', 'Consulting'), ('IT Development Services', 'IT Development Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Media Creators', 'Media Creators'), ('E-commerce', 'E-commerce'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Education and Training', 'Education and Training'), ('Health and Wellness', 'Health and Wellness')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-light-danger', 'card-light-danger'), ('card-light-blue', 'card-light-blue'), ('card-tale', 'card-tale'), ('card-dark-blue', 'card-dark-blue')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('News', 'News'), ('Guides and Manuals', 'Guides and Manuals'), ('Events and Conferences', 'Events and Conferences'), ('Tips and Tricks', 'Tips and Tricks'), ('Interviews', 'Interviews'), ('Inspiration', 'Inspiration'), ('Tutorials', 'Tutorials')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 27, 10, 52, 7, 564942)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('No Selected', 'No Selected'), ('Initial Payment', 'Initial Payment'), ('Promotional Discount', 'Promotional Discount'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription')], max_length=60),
        ),
        migrations.AlterField(
            model_name='jobapplication',
            name='cv',
            field=models.FileField(blank=True, null=True, upload_to='cv/', verbose_name='Upload CV'),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 1', 'Style Template 1'), ('Style Template 4', 'Style Template 4'), ('Style Template 3', 'Style Template 3'), ('Style Template 2', 'Style Template 2')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('No Selected', 'No Selected'), ('Stela Design', 'Stela Design'), ('Stela Websites', 'Stela Websites'), ('Cloud Domains', 'Cloud Domains'), ('Stela Marketing', 'Stela Marketing'), ('Store', 'Store')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 2', 'Step 2'), ('Step 3', 'Step 3'), ('Step 4', 'Step 4')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('Terms and Conditions', 'Terms and Conditions'), ('Privacy Policy', 'Privacy Policy'), ('Disclaimer', 'Disclaimer'), ('Return Policy', 'Return Policy'), ('billing_terms', 'Monthly Billing Terms'), ('Cookie Policy', 'Cookie Policy'), ('budget_development_terms', 'Budget Development Terms'), ('budget_design_terms', 'Budget Design Terms'), ('monthly_terms', 'Billing Terms'), ('budget_marketing_terms', 'Budget Marketing Terms')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Wikipedia', 'Wikipedia'), ('Instagram', 'Instagram'), ('X', 'X'), ('Tiktok', 'Tiktok'), ('Facebook', 'Facebook'), ('Github', 'Github'), ('Linkedin', 'Linkedin'), ('Youtube', 'Youtube')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('My delivery has been delayed', 'My delivery has been delayed'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('Payments Issue', 'Payments Issue'), ('Others', 'Others'), ('My account has an error', 'My account has an error'), ('I have a problem with my project', 'I have a problem with my project')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Paypal', 'Paypal'), ('Zelle', 'Zelle'), ('Binance', 'Binance')], max_length=100, verbose_name='Type of Wallet'),
        ),
        migrations.CreateModel(
            name='PhotoGallery',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=200)),
                ('description', models.TextField(blank=True)),
                ('image', models.ImageField(upload_to='photos/')),
                ('date_uploaded', models.DateTimeField(auto_now_add=True)),
                ('biography', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='photos', to='stela_control.biography')),
            ],
        ),
    ]
