{% load i18n %}
{% load crispy_forms_tags %}
<form action="" method="post" enctype="multipart/form-data" onsubmit="newbtnDisabled()">
    <input type="hidden" name="csrfmiddlewaretoken" id="token6">
    <div class="modal-body mid-modal-scroll modal1">
        <h3 class="fs-5 oxanium text-center">{% trans "Description Company" %}</h3>
            {{form3.media}}
            {{form3|crispy}}
            <h3 class="fs-5 oxanium text-center">{% trans "Add Contact Info" %}</h3>
            {{form4.media}}
            <label class="fw-bold oxanium" for="">{% trans "Address" %}</label>
            {{form4|crispy}}
            <label class="fw-bold oxanium" for="">{% trans "Phone" %}</label>
            {{form5|crispy}}
        <h3 class="fs-5 oxanium text-center">{% trans "Social Links" %}</h3>
        <div id="new-formset6">
            {{ formset6.management_form }}
                {% for form in formset6 %}
                <div id="form-0" class="new-formset6 pt-2">
                    {{form|crispy}}
                    {{form|as_crispy_errors}}
                </div>
                {% endfor %}
            <div id="new-empty-form6" class="d-none">
                {{formset6.empty_form.media}}
                {{formset6.empty_form|crispy}}
            </div>
        </div>
        <div class="d-flex justify-content-between my-3">
            <button class="btn-clear" type="button" onclick="updateFormset4()"><i class="fa-solid fa-plus"></i> {% trans " Add" %}</button>
            <button class="btn-clear" type="button" onclick="updateClear4()"><i class="fa-solid fa-minus"></i> {% trans "Remove" %}</button>
        </div>
        <p class="response-footer text-link fw-bold oxanium"></p>
        <input type="hidden" name="form-id" value="updateFooter">
        <div class="row justify-content-end p-3">
            <div class="col-lg-4">
                <button type="submit" id="btn-footer" name="btn-footer" class="btn btn-shappire center-btn btn-block new-btn-form d-flex">{% trans "Send" %} <i class="fa-solid fa-paper-plane mx-2"></i></button>      
            </div>
        </div>
    </div>    
</form>