{% load i18n %}
{% load crispy_forms_tags %}     
<div id="formset">
    {{ formset.management_form }}
        {% for form in formset %}
        <div id="form-0" class="formset pt-2">
            {{form|crispy}}
        </div>
        {% endfor %}
    <div id="empty-form" class="d-none">
        {{formset.empty_form|crispy}}
    </div>
</div>
<div class="d-flex justify-content-between my-3">
    <button class="btn-clear" type="button" onclick="addFormset()"><i class="fa-solid fa-plus"></i> {% trans " Add" %}</button>
    <button class="btn-clear" type="button" onclick="clearFormset()"><i class="fa-solid fa-minus"></i> {% trans "Remove" %}</button>
</div>
<input type="hidden" name="form_id" value="{{form_name}}">
{% if pk %}
    <input type="hidden" name="pk" value="{{pk}}">
{% endif %}