# Generated by Django 4.2.1 on 2023-11-17 16:26

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0002_alter_billingrecipt_option_alter_company_business_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('budget_design', 'Budget Design'), ('Monthly charge', 'Monthly charge'), ('budget_marketing', 'Budget Marketing'), ('Others', 'Others'), ('budget_development', 'Budget Development'), ('Billing receipt', 'Billing receipt')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('E-commerce', 'E-commerce'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('Education and Training', 'Education and Training'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('Consulting', 'Consulting'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Health and Wellness', 'Health and Wellness'), ('Media Creators', 'Media Creators'), ('IT Development Services', 'IT Development Services'), ('Repair and Maintenance Services', 'Repair and Maintenance Services')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-light-danger', 'card-light-danger'), ('card-light-blue', 'card-light-blue'), ('card-tale', 'card-tale'), ('card-dark-blue', 'card-dark-blue')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Tutorials', 'Tutorials'), ('News', 'News'), ('Interviews', 'Interviews'), ('Inspiration', 'Inspiration'), ('Events and Conferences', 'Events and Conferences'), ('Guides and Manuals', 'Guides and Manuals'), ('Tips and Tricks', 'Tips and Tricks')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 11, 17, 13, 26, 32, 163469)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('No Selected', 'No Selected'), ('Initial Payment', 'Initial Payment'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('Promotional Discount', 'Promotional Discount')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Send', 'Send'), ('Draft', 'Draft')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 4', 'Style Template 4'), ('Style Template 2', 'Style Template 2'), ('Style Template 3', 'Style Template 3'), ('Style Template 1', 'Style Template 1')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('No Selected', 'No Selected'), ('Stela Marketing', 'Stela Marketing'), ('Stela Design', 'Stela Design'), ('Cloud Domains', 'Cloud Domains'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('Stela Websites', 'Stela Websites'), ('Store', 'Store')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 2', 'Step 2'), ('Step 3', 'Step 3'), ('Step 4', 'Step 4')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('monthly_terms', 'Billing Terms'), ('billing_terms', 'Monthly Billing Terms'), ('budget_design_terms', 'Budget Design Terms'), ('budget_development_terms', 'Budget Development Terms'), ('Return Policy', 'Return Policy'), ('Cookie Policy', 'Cookie Policy'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('Disclaimer', 'Disclaimer'), ('Privacy Policy', 'Privacy Policy'), ('Terms and Conditions', 'Terms and Conditions')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Youtube', 'Youtube'), ('Facebook', 'Facebook'), ('Tiktok', 'Tiktok'), ('Instagram', 'Instagram'), ('Linkedin', 'Linkedin'), ('X', 'X'), ('Github', 'Github')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('My delivery has been delayed', 'My delivery has been delayed'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('Payments Issue', 'Payments Issue'), ('I have a problem with my project', 'I have a problem with my project'), ('Others', 'Others'), ('My account has an error', 'My account has an error')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Binance', 'Binance'), ('Paypal', 'Paypal'), ('Zelle', 'Zelle')], max_length=100, verbose_name='Type of Wallet'),
        ),
    ]
