{% load i18n %}
{% load crispy_forms_tags %}
<h3 class="fs-5 oxanium text-center">{% trans "Color" %}</h3>
{{form|crispy}}
<input type="hidden" name="pk" value="{{obj}}">
<input type="hidden" name="form-id" value="colorForm">