{% load i18n %}
{% load crispy_forms_tags %}
{{form|crispy}}
<input type="hidden" name="form-id" value="{{form_name}}">
{% if pk %}
    <input type="hidden" name="pk" value="{{pk}}">
{% else %}
{% endif %}