{% load crispy_forms_tags %}
{% load i18n %}
<div class="row">
    <div class="col-lg-6">
        {{form.status|as_crispy_field}}
    </div>
    <div class="col-lg-6">
        {{form.schedule|as_crispy_field}}
    </div>
</div>
<div class="preload-page upload-page d-none"></div>
<div class="caption-loader2">
    <label for=""><small class="text-center">{% trans "Footer media" %}</small></label>              
    {{form.caption|as_crispy_field}}
</div>