# Generated by Django 5.0 on 2023-12-21 18:24

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0016_alter_billingrecipt_option_alter_company_business_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='modules',
            name='slug',
            field=models.SlugField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('Others', 'Others'), ('budget_marketing', 'Budget Marketing'), ('budget_design', 'Budget Design'), ('Billing receipt', 'Billing receipt'), ('budget_development', 'Budget Development'), ('Monthly charge', 'Monthly charge')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Education and Training', 'Education and Training'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Restaurants and Food Services', 'Restaurants and Food Services'), ('Consulting', 'Consulting'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Health and Wellness', 'Health and Wellness'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('E-commerce', 'E-commerce'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Media Creators', 'Media Creators'), ('IT Development Services', 'IT Development Services')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-tale', 'card-tale'), ('card-light-danger', 'card-light-danger'), ('card-light-blue', 'card-light-blue'), ('card-dark-blue', 'card-dark-blue')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Inspiration', 'Inspiration'), ('Events and Conferences', 'Events and Conferences'), ('Guides and Manuals', 'Guides and Manuals'), ('News', 'News'), ('Interviews', 'Interviews'), ('Tips and Tricks', 'Tips and Tricks'), ('Tutorials', 'Tutorials')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 21, 15, 24, 18, 208550)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('Promotional Discount', 'Promotional Discount'), ('Initial Payment', 'Initial Payment'), ('No Selected', 'No Selected')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 1', 'Style Template 1'), ('Style Template 3', 'Style Template 3'), ('Style Template 2', 'Style Template 2'), ('Style Template 4', 'Style Template 4')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Stela Marketing', 'Stela Marketing'), ('No Selected', 'No Selected'), ('Stela Design', 'Stela Design'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('Store', 'Store'), ('Stela Websites', 'Stela Websites'), ('Cloud Domains', 'Cloud Domains')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 4', 'Step 4'), ('Step 3', 'Step 3'), ('Step 2', 'Step 2')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('Return Policy', 'Return Policy'), ('Cookie Policy', 'Cookie Policy'), ('monthly_terms', 'Billing Terms'), ('Terms and Conditions', 'Terms and Conditions'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('billing_terms', 'Monthly Billing Terms'), ('Privacy Policy', 'Privacy Policy'), ('budget_design_terms', 'Budget Design Terms'), ('budget_development_terms', 'Budget Development Terms'), ('Disclaimer', 'Disclaimer')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Github', 'Github'), ('Wikipedia', 'Wikipedia'), ('Tiktok', 'Tiktok'), ('Linkedin', 'Linkedin'), ('Instagram', 'Instagram'), ('Facebook', 'Facebook'), ('Youtube', 'Youtube'), ('X', 'X')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('Payments Issue', 'Payments Issue'), ('Others', 'Others'), ('I have a problem with my project', 'I have a problem with my project'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('My account has an error', 'My account has an error'), ('My delivery has been delayed', 'My delivery has been delayed')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Paypal', 'Paypal'), ('Binance', 'Binance'), ('Zelle', 'Zelle')], max_length=100, verbose_name='Type of Wallet'),
        ),
    ]
