{% autoescape off %}
Hola {{ user.username }},

Tu cuenta ha sido creada exitosamente. Por favor ingresa el link a continuación

http://{{ domain }}{% url 'accounts:activate' uidb64=uid token=token %}
{% endautoescape %}