{% load crispy_forms_tags %}
<div class="form-group">
    {{form.email|as_crispy_field}}
</div>
<div class="form-group">
    {{form.username|as_crispy_field}}
</div>
<div class="form-group">
    {{form.full_name|as_crispy_field}}
</div>
<div class="form-group">
    {{form.address|as_crispy_field}}
</div>
<div class="form-group">
    {{form.phone_number|as_crispy_field}}
</div>
<div class="form-group">
    {{form.country_profile|as_crispy_field}}
</div>
<div class="form-group">
    {{form.city_profile|as_crispy_field}}
</div>
<div class="form-group">
    {{form.password1|as_crispy_field}}
    <span toggle="#id_password1" class="zmdi zmdi-eye-off field-icon toggle-password"></span>
</div>
<div class="form-group">
    {{form.password2|as_crispy_field}}
</div>